==> pmml-model-1.0.0-sources.jar: org/dmg/pmml/Counts.java <==

package org.dmg.pmml;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="totalFreq" use="required" type="{http://www.dmg.org/PMML-4_1}NUMBER" />
 *       &lt;attribute name="missingFreq" type="{http://www.dmg.org/PMML-4_1}NUMBER" />
 *       &lt;attribute name="invalidFreq" type="{http://www.dmg.org/PMML-4_1}NUMBER" />
 *       &lt;attribute name="cardinality" type="{http://www.w3.org/2001/XMLSchema}nonNegativeInteger" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "Counts")
public class Counts
    extends PMMLObject
    implements Equals, HashCode
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlAttribute(name = "totalFreq", required = true)
    protected double totalFreq;
    @XmlAttribute(name = "missingFreq")
    protected Double missingFreq;
    @XmlAttribute(name = "invalidFreq")
    protected Double invalidFreq;
    @XmlAttribute(name = "cardinality")
    @XmlSchemaType(name = "nonNegativeInteger")
    protected BigInteger cardinality;

    @Deprecated
    public Counts() {
        super();
    }

    public Counts(final double totalFreq) {
        super();
        this.totalFreq = totalFreq;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the totalFreq property.
     * 
     */
    public double getTotalFreq() {
        return totalFreq;
    }

    /**
     * Sets the value of the totalFreq property.
     * 
     */
    public void setTotalFreq(double value) {
        this.totalFreq = value;
    }

    /**
     * Gets the value of the missingFreq property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getMissingFreq() {
        return missingFreq;
    }

    /**
     * Sets the value of the missingFreq property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setMissingFreq(Double value) {
        this.missingFreq = value;
    }

    /**
     * Gets the value of the invalidFreq property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getInvalidFreq() {
        return invalidFreq;
    }

    /**
     * Sets the value of the invalidFreq property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setInvalidFreq(Double value) {
        this.invalidFreq = value;
    }

    /**
     * Gets the value of the cardinality property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getCardinality() {
        return cardinality;
    }

    /**
     * Sets the value of the cardinality property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setCardinality(BigInteger value) {
        this.cardinality = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof Counts)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final Counts that = ((Counts) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            double lhsTotalFreq;
            lhsTotalFreq = (true?this.getTotalFreq(): 0.0D);
            double rhsTotalFreq;
            rhsTotalFreq = (true?that.getTotalFreq(): 0.0D);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "totalFreq", lhsTotalFreq), LocatorUtils.property(thatLocator, "totalFreq", rhsTotalFreq), lhsTotalFreq, rhsTotalFreq)) {
                return false;
            }
        }
        {
            Double lhsMissingFreq;
            lhsMissingFreq = this.getMissingFreq();
            Double rhsMissingFreq;
            rhsMissingFreq = that.getMissingFreq();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "missingFreq", lhsMissingFreq), LocatorUtils.property(thatLocator, "missingFreq", rhsMissingFreq), lhsMissingFreq, rhsMissingFreq)) {
                return false;
            }
        }
        {
            Double lhsInvalidFreq;
            lhsInvalidFreq = this.getInvalidFreq();
            Double rhsInvalidFreq;
            rhsInvalidFreq = that.getInvalidFreq();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "invalidFreq", lhsInvalidFreq), LocatorUtils.property(thatLocator, "invalidFreq", rhsInvalidFreq), lhsInvalidFreq, rhsInvalidFreq)) {
                return false;
            }
        }
        {
            BigInteger lhsCardinality;
            lhsCardinality = this.getCardinality();
            BigInteger rhsCardinality;
            rhsCardinality = that.getCardinality();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "cardinality", lhsCardinality), LocatorUtils.property(thatLocator, "cardinality", rhsCardinality), lhsCardinality, rhsCardinality)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            double theTotalFreq;
            theTotalFreq = (true?this.getTotalFreq(): 0.0D);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "totalFreq", theTotalFreq), currentHashCode, theTotalFreq);
        }
        {
            Double theMissingFreq;
            theMissingFreq = this.getMissingFreq();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "missingFreq", theMissingFreq), currentHashCode, theMissingFreq);
        }
        {
            Double theInvalidFreq;
            theInvalidFreq = this.getInvalidFreq();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "invalidFreq", theInvalidFreq), currentHashCode, theInvalidFreq);
        }
        {
            BigInteger theCardinality;
            theCardinality = this.getCardinality();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "cardinality", theCardinality), currentHashCode, theCardinality);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

}

==> pmml-model-1.0.2-sources.jar: org/dmg/pmml/Counts.java <==

package org.dmg.pmml;

import java.math.BigInteger;
import java.util.ArrayList;
import java.util.List;
import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.Equals;
import org.jvnet.jaxb2_commons.lang.EqualsStrategy;
import org.jvnet.jaxb2_commons.lang.HashCode;
import org.jvnet.jaxb2_commons.lang.HashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBEqualsStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBHashCodeStrategy;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;
import org.jvnet.jaxb2_commons.locator.util.LocatorUtils;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://www.dmg.org/PMML-4_1}Extension" maxOccurs="unbounded" minOccurs="0"/>
 *       &lt;/sequence>
 *       &lt;attribute name="totalFreq" use="required" type="{http://www.dmg.org/PMML-4_1}NUMBER" />
 *       &lt;attribute name="missingFreq" type="{http://www.dmg.org/PMML-4_1}NUMBER" />
 *       &lt;attribute name="invalidFreq" type="{http://www.dmg.org/PMML-4_1}NUMBER" />
 *       &lt;attribute name="cardinality" type="{http://www.w3.org/2001/XMLSchema}nonNegativeInteger" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "extensions"
})
@XmlRootElement(name = "Counts")
public class Counts
    extends PMMLObject
    implements Equals, HashCode, ToString
{

    @XmlElement(name = "Extension")
    protected List<Extension> extensions;
    @XmlAttribute(name = "totalFreq", required = true)
    protected double totalFreq;
    @XmlAttribute(name = "missingFreq")
    protected Double missingFreq;
    @XmlAttribute(name = "invalidFreq")
    protected Double invalidFreq;
    @XmlAttribute(name = "cardinality")
    @XmlSchemaType(name = "nonNegativeInteger")
    protected BigInteger cardinality;

    @Deprecated
    public Counts() {
        super();
    }

    public Counts(final double totalFreq) {
        super();
        this.totalFreq = totalFreq;
    }

    /**
     * Gets the value of the extensions property.
     * 
     * <p>
     * This accessor method returns a reference to the live list,
     * not a snapshot. Therefore any modification you make to the
     * returned list will be present inside the JAXB object.
     * This is why there is not a <CODE>set</CODE> method for the extensions property.
     * 
     * <p>
     * For example, to add a new item, do as follows:
     * <pre>
     *    getExtensions().add(newItem);
     * </pre>
     * 
     * 
     * <p>
     * Objects of the following type(s) are allowed in the list
     * {@link Extension }
     * 
     * 
     */
    public List<Extension> getExtensions() {
        if (extensions == null) {
            extensions = new ArrayList<Extension>();
        }
        return this.extensions;
    }

    /**
     * Gets the value of the totalFreq property.
     * 
     */
    public double getTotalFreq() {
        return totalFreq;
    }

    /**
     * Sets the value of the totalFreq property.
     * 
     */
    public void setTotalFreq(double value) {
        this.totalFreq = value;
    }

    /**
     * Gets the value of the missingFreq property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getMissingFreq() {
        return missingFreq;
    }

    /**
     * Sets the value of the missingFreq property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setMissingFreq(Double value) {
        this.missingFreq = value;
    }

    /**
     * Gets the value of the invalidFreq property.
     * 
     * @return
     *     possible object is
     *     {@link Double }
     *     
     */
    public Double getInvalidFreq() {
        return invalidFreq;
    }

    /**
     * Sets the value of the invalidFreq property.
     * 
     * @param value
     *     allowed object is
     *     {@link Double }
     *     
     */
    public void setInvalidFreq(Double value) {
        this.invalidFreq = value;
    }

    /**
     * Gets the value of the cardinality property.
     * 
     * @return
     *     possible object is
     *     {@link BigInteger }
     *     
     */
    public BigInteger getCardinality() {
        return cardinality;
    }

    /**
     * Sets the value of the cardinality property.
     * 
     * @param value
     *     allowed object is
     *     {@link BigInteger }
     *     
     */
    public void setCardinality(BigInteger value) {
        this.cardinality = value;
    }

    public boolean equals(ObjectLocator thisLocator, ObjectLocator thatLocator, Object object, EqualsStrategy strategy) {
        if (!(object instanceof Counts)) {
            return false;
        }
        if (this == object) {
            return true;
        }
        if (!super.equals(thisLocator, thatLocator, object, strategy)) {
            return false;
        }
        final Counts that = ((Counts) object);
        {
            List<Extension> lhsExtensions;
            lhsExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            List<Extension> rhsExtensions;
            rhsExtensions = (((that.extensions!= null)&&(!that.extensions.isEmpty()))?that.getExtensions():null);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "extensions", lhsExtensions), LocatorUtils.property(thatLocator, "extensions", rhsExtensions), lhsExtensions, rhsExtensions)) {
                return false;
            }
        }
        {
            double lhsTotalFreq;
            lhsTotalFreq = (true?this.getTotalFreq(): 0.0D);
            double rhsTotalFreq;
            rhsTotalFreq = (true?that.getTotalFreq(): 0.0D);
            if (!strategy.equals(LocatorUtils.property(thisLocator, "totalFreq", lhsTotalFreq), LocatorUtils.property(thatLocator, "totalFreq", rhsTotalFreq), lhsTotalFreq, rhsTotalFreq)) {
                return false;
            }
        }
        {
            Double lhsMissingFreq;
            lhsMissingFreq = this.getMissingFreq();
            Double rhsMissingFreq;
            rhsMissingFreq = that.getMissingFreq();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "missingFreq", lhsMissingFreq), LocatorUtils.property(thatLocator, "missingFreq", rhsMissingFreq), lhsMissingFreq, rhsMissingFreq)) {
                return false;
            }
        }
        {
            Double lhsInvalidFreq;
            lhsInvalidFreq = this.getInvalidFreq();
            Double rhsInvalidFreq;
            rhsInvalidFreq = that.getInvalidFreq();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "invalidFreq", lhsInvalidFreq), LocatorUtils.property(thatLocator, "invalidFreq", rhsInvalidFreq), lhsInvalidFreq, rhsInvalidFreq)) {
                return false;
            }
        }
        {
            BigInteger lhsCardinality;
            lhsCardinality = this.getCardinality();
            BigInteger rhsCardinality;
            rhsCardinality = that.getCardinality();
            if (!strategy.equals(LocatorUtils.property(thisLocator, "cardinality", lhsCardinality), LocatorUtils.property(thatLocator, "cardinality", rhsCardinality), lhsCardinality, rhsCardinality)) {
                return false;
            }
        }
        return true;
    }

    public boolean equals(Object object) {
        final EqualsStrategy strategy = JAXBEqualsStrategy.INSTANCE;
        return equals(null, null, object, strategy);
    }

    public int hashCode(ObjectLocator locator, HashCodeStrategy strategy) {
        int currentHashCode = super.hashCode(locator, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "extensions", theExtensions), currentHashCode, theExtensions);
        }
        {
            double theTotalFreq;
            theTotalFreq = (true?this.getTotalFreq(): 0.0D);
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "totalFreq", theTotalFreq), currentHashCode, theTotalFreq);
        }
        {
            Double theMissingFreq;
            theMissingFreq = this.getMissingFreq();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "missingFreq", theMissingFreq), currentHashCode, theMissingFreq);
        }
        {
            Double theInvalidFreq;
            theInvalidFreq = this.getInvalidFreq();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "invalidFreq", theInvalidFreq), currentHashCode, theInvalidFreq);
        }
        {
            BigInteger theCardinality;
            theCardinality = this.getCardinality();
            currentHashCode = strategy.hashCode(LocatorUtils.property(locator, "cardinality", theCardinality), currentHashCode, theCardinality);
        }
        return currentHashCode;
    }

    public int hashCode() {
        final HashCodeStrategy strategy = JAXBHashCodeStrategy.INSTANCE;
        return this.hashCode(null, strategy);
    }

    public String toString() {
        final ToStringStrategy strategy = JAXBToStringStrategy.INSTANCE;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy strategy) {
        super.appendFields(locator, buffer, strategy);
        {
            List<Extension> theExtensions;
            theExtensions = (((this.extensions!= null)&&(!this.extensions.isEmpty()))?this.getExtensions():null);
            strategy.appendField(locator, this, "extensions", buffer, theExtensions);
        }
        {
            double theTotalFreq;
            theTotalFreq = (true?this.getTotalFreq(): 0.0D);
            strategy.appendField(locator, this, "totalFreq", buffer, theTotalFreq);
        }
        {
            Double theMissingFreq;
            theMissingFreq = this.getMissingFreq();
            strategy.appendField(locator, this, "missingFreq", buffer, theMissingFreq);
        }
        {
            Double theInvalidFreq;
            theInvalidFreq = this.getInvalidFreq();
            strategy.appendField(locator, this, "invalidFreq", buffer, theInvalidFreq);
        }
        {
            BigInteger theCardinality;
            theCardinality = this.getCardinality();
            strategy.appendField(locator, this, "cardinality", buffer, theCardinality);
        }
        return buffer;
    }

}
